# fontello font demo

show codes
 icon-ok0xe800
 icon-home0xe801
 icon-help-circle0xe802
 icon-book0xe803
 icon-github-circled0xe804
 icon-cancel-circled0xe805
 icon-dot-circled0xe806
 icon-circle-empty0xe807
 icon-check-off0xe808
 icon-check-on0xe809
 icon-ok-circled0xe80a
 icon-angle-circled-right0xe80b
 icon-pencil0xe80c
 icon-doc0xe80d
 icon-doc-inv0xe80e
 icon-hamburger0xe80f
 icon-cog0xe810
 icon-left0xe811
 icon-menu-outline0xe812
 icon-plus-circle0xe813
 icon-down-circle0xe814
 icon-up-circle0xe815
 icon-angle-circled-left0xe816
 icon-trash0xe817
 icon-chart-line-10xe818
 icon-download0xe819
 icon-user0xe81a
 icon-menu0xe81b
 icon-sidebar0xe81c
 icon-sidebar-open0xe81d
 icon-lightbulb0xe81e
 icon-mail0xe81f
 icon-key-10xe820
 icon-logout0xe821
 icon-spin60xe822
 icon-flow-branch0xe823
 icon-clipboard0xe824
 icon-circles0xe825
 icon-oira-risk-assessment0xe826
 icon-publish-old0xe827
 icon-share0xe828
 icon-globe0xe829
 icon-right-open0xe82a
 icon-search0xe82b
 icon-info-circle0xe82c
 icon-oira-tool0xe82d
 icon-published0xe82e
 icon-unpublished0xe82f
 icon-publish0xe830
 icon-cancel-10xe831
 icon-resize-full0xe832
 icon-plus0xe833
 icon-clock0xe834
 icon-archive-front0xe835
 icon-star0xe836
 icon-archive0xe837
 icon-star-empty0xe838
 icon-menu-bars0xe839
 icon-picture0xe842
 icon-bank0xe84c
 icon-ellipsis0xe865
 icon-building0xe86e
 icon-history0xe885
 icon-cancel0xe899
 icon-arrows-cw0xe89c
 icon-picture-10xe89f
 icon-eye0xe8a0
 icon-eye-off0xe8a1
 icon-lock0xe8a3
 icon-lock-open0xe8a4
 icon-award0xe8aa
 icon-award-10xe8ab
 icon-attention-circled0xe8ae
 icon-road0xe8e5
 icon-twitter0xf099
 icon-certificate0xf0a3
 icon-menu-10xf0c9
 icon-chat-empty0xf0e6
 icon-angle-double-right0xf101
 icon-lock-open-alt0xf13e
 icon-ellipsis-vertical0xf142
 icon-building-filled0xf1ad
 icon-tree0xf1bb
 icon-eyedropper0xf1fb
 icon-facebook0xf230
 icon-clone0xf24d